<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORIES","");
define("_WHOSONLINE"," ");
define("_ALLTOPICS"," ");
define("_ARTICLES","");
define("_ALL","");
define("_REVIEWS","");
define("_NOSUBJECT"," ");
define("_SCORE"," ( )");
define("_SUBJECT","");
define("_EMAIL","Email");
define("_ICQ"," ICQ");
define("_AIM"," ");
define("_YIM"," ");
define("_MSNM"," MSNM");
define("_LOCATION","");
define("_OCCUPATION","");
define("_INTERESTS","");
define("_SIGNATURE","");
define("_EXTRAINFO"," ");
define("_OPTION","");
define("_YOUARELOGGEDOUT","    ");
define("_REQUIRED","()");
define("_SAVECHANGES"," ");
define("_HOMECONFIG"," ");
define("_FROM","");
define("_DATE","");
define("_USERNOTINDB","        .");
define("_TO","");
define("_SUBMIT","");
define("_MODIFY","");
define("_THEREARE","");
define("_PAGETITLE","  ");
define("_PAGEURL","URL ");
define("_CATEGORY","");
define("_ADDURL"," URL");
define("_SHOW","");
define("_DAYS","");
define("_DESCRIPTION","");
define("_HITS","");
define("_TITLE","");
define("_STAFF","");
define("_LINKID","ID ");
define("_LINKTITLE"," ");
define("_URL","URL");
define("_FILEURL"," ");
define("_DOWNLOADID"," ID ");
define("_DOWNLOADTITLE"," ");
define("_FUNCTIONS","");
define("_PRODUCTTITLE","");
define("_PAGEBREAK","       <b>&lt;!--pagebreak--&gt;</b>         .");
define("_RELATEDLINK","  ");
define("_REVIEWER"," ?");
define("_REVIEWID"," ID");
define("_YES","");
define("_NO","");
define("_SELECTTOPIC"," ");
define("_AREYOUSURE","      URL? ");
define("_PREVIEW","");
define("_OK","Ok!");
define("_SEND","");
define("_HELLO"," ");
define("_ADMINLOGIN","     ");
define("_ADMINID","ID ");
define("_ADMINMENU"," ");
define("_BANNERSADMIN"," banners");
define("_ONLINEMANUAL"," ");
define("_ADMINLOGOUT","  / ");
define("_AUTOMATEDARTICLES"," ");
define("_NOFUNCTIONS","---------");
define("_NOAUTOARTICLES","   ");
define("_LAST","");
define("_STORYID","ID ");
define("_GO","!");
define("_CURRENTPOLL","  ()");
define("_QUESTION","");
define("_ANSWER","");
define("_ADDSTORY"," ");
define("_EDITADMINS"," ");
define("_PREFERENCES","");
define("_BLOCKS","");
define("_FORUMMANAGER","  ");
define("_FORUMRANKS","-----");
define("_FORUMCONFIG","-----");
define("_DOWNLOAD","");
define("_SECTIONSMANAGER"," ");
define("_ADMPOLLS","");
define("_EDITUSERS"," ");
define("_WEBLINKS"," ");
define("_FAQ"," ");
define("_MESSAGES","");
define("_TOPICSMANAGER"," ");
define("_BLOCKSADMIN"," ");
define("_POSITION"," ");
define("_WEIGHT","");
define("_STATUS","");
define("_LEFTBLOCK"," ");
define("_LEFT"," ");
define("_RIGHT"," ");
define("_RIGHTBLOCK"," ");
define("_BLOCKUP"," ");
define("_BLOCKDOWN"," ");
define("_ACTIVE","");
define("_DEACTIVATE","");
define("_INACTIVE","");
define("_ACTIVATE","");
define("_TYPE","");
define("_ADDNEWBLOCK","  ");
define("_RSSFILE","URL  RSS/RDF");
define("_CUSTOM","");
define("_SETUPHEADLINES","( \"\"    URL              )");
define("_CONTENT","");
define("_IFRSSWARNING","   URL        !");
define("_ACTIVATE2",";");
define("_REFRESHTIME"," ");
define("_HOUR"," ");
define("_ONLYHEADLINES","(  )");
define("_CREATEBLOCK"," ");
define("_RSSFAIL","     URL  RSS ");
define("_RSSTRYAGAIN","   URL     RSS   . ");
define("_EDITBLOCK"," ");
define("_RSSCONTENT","(RSS/RDF )");
define("_BLOCK","");
define("_SAVEBLOCK"," ");
define("_BLOCKACTIVATION"," ");
define("_BLOCKPREVIEW","  ");
define("_WANT2ACTIVATE","     ;");
define("_ARESUREDELBLOCK","        ");
define("_HEADLINESADMIN"," ");
define("_SITENAME"," ");
define("_ADDHEADLINE"," ");
define("_ADD"," ");
define("_EDITHEADLINE"," ");
define("_SURE2DELHEADLINE",":          ; ");
define("_PUBLISHINHOME","   ;");
define("_ONLYIFCATSELECTED","       <i>Articles</i> ");
define("_CATEGORIESADMIN"," ");
define("_CATEGORYADD","  ");
define("_CATNAME"," ");
define("_SAVE","");
define("_EDITCATEGORY"," ");
define("_ASELECTCATEGORY"," ");
define("_NOARTCATEDIT","     <i>Articles</i> ");
define("_CATEGORYNAME"," ");
define("_DELETECATEGORY"," ");
define("_SELECTCATDEL","      ");
define("_CATDELETED","  ! (  )");
define("_GOTOADMIN","   ");
define("_WARNING","");
define("_THECATEGORY"," ");
define("_HAS","");
define("_STORIESINSIDE","  ");
define("_DELCATWARNING1","             ");
define("_DELCATWARNING2","         .");
define("_DELCATWARNING3","   ;");
define("_YESDEL","!   !");
define("_NOMOVE","!     ");
define("_MOVESTORIES","       .");
define("_ALLSTORIES","   ");
define("_WILLBEMOVED"," .");
define("_SELECTNEWCAT","    ");
define("_MOVEDONE","!   !");
define("_CATEXISTS","    !");
define("_CATSAVED","  !");
define("_CATADDED","  !");
define("_ARTICLEADMIN"," / ");
define("_AUTOSTORYEDIT","  ");
define("_STORYTEXT","   ");
define("_EXTENDEDTEXT"," ");
define("_ARESUREURL","(    URL; -----;)");
define("_NOTES","");
define("_CHNGPROGRAMSTORY","      ");
define("_NOWIS","  ");
define("_DAY","");
define("_UMONTH","");
define("_YEAR","");
define("_NOTAUTHORIZED1","       !");
define("_NOTAUTHORIZED2","     /        ");
define("_SUBMISSIONSADMIN"," Y ");
define("_NAME","");
define("_PROGRAMSTORY","    ;");
define("_DELETESTORY"," ");
define("_PREVIEWSTORY","  ");
define("_POSTSTORY"," ");
define("_EDITARTICLE"," ");
define("_REMOVESTORY","           ");
define("_ANDCOMMENTS","    ;");
define("_ADDARTICLE","  ");
define("_NOSUBMISSIONS","  ");
define("_NEWSUBMISSIONS","  ");
define("_USERADMIN"," ");
define("_EDITUSER"," ");
define("_ADDUSER","  ");
define("_FAKEEMAIL"," () Email");
define("_ALLOWUSERS","       (  )  email  ");
define("_ADDUSERBUT"," ");
define("_USERUPDATE"," ");
define("_USERID","   ");
define("_RETYPEPASSWD","   ");
define("_FORCHANGES","(  )");
define("_USERNOEXIST","   !");
define("_PASSWDNOMATCH"," ,      .      ");
define("_DELETEUSER"," ");
define("_SURE2DELETE","       ");
define("_NEEDTOCOMPLETE","      ");
define("_AUTHORSADMIN"," ");
define("_MODIFYINFO"," ");
define("_MAINACCOUNT","-----");
define("_DELAUTHOR"," ");
define("_GODNOTDEL","*(  admin    )");
define("_ADDAUTHOR","  ");
define("_REQUIREDNOCHANGE","(,       )");
define("_PERMISSIONS","");
define("_TOPICS","");
define("_USERS","");
define("_SURVEYS","");
define("_SECTIONS","");
define("_SUPERUSER","");
define("_SUPERWARNING",":     ,      !");
define("_ADDAUTHOR2"," ");
define("_PUBLISHEDSTORIES","   ");
define("_SELECTNEWADMIN","         ");
define("_CREATIONERROR","  ");
define("_COMPLETEFIELDS","      ");
define("_AUTHORDEL"," ");
define("_AUTHORDELSURE","      ");
define("_MESSAGESADMIN"," ");
define("_MESSAGETITLE","");
define("_MESSAGECONTENT"," ");
define("_EXPIRATION","() ");
define("_CHANGEDATE","     !");
define("_IFYOUACTIVE","     ,       )");
define("_VIEWPRIV","  ;");
define("_MVALL","   (   )");
define("_MVANON","   ");
define("_MVUSERS","    ");
define("_MVADMIN"," ");
define("_CURRENTTOPICS","  ");
define("_CLICK2EDIT","      ");
define("_ADDATOPIC","   ");
define("_TOPICNAME"," ");
define("_TOPICNAME1","(     -  20 ");
define("_TOPICNAME2","(: )");
define("_TOPICTEXT"," ");
define("_TOPICTEXT1","(     -  10 )");
define("_TOPICTEXT2","(:   )");
define("_TOPICIMAGE"," ");
define("_ADDTOPIC"," ");
define("_EDITTOPIC","  ");
define("_ADDRELATED","   ");
define("_ACTIVERELATEDLINKS","  ");
define("_NORELATED","       ");
define("_EDITRELATED","   ");
define("_DELETETOPIC"," ");
define("_TOPICDELSURE","        ");
define("_TOPICDELSURE1","           ");
define("_SITECONFIG","  ");
define("_GENSITEINFO","  (  )");
define("_SITEURL","URL ");
define("_SITELOGO"," ");
define("_SITESLOGAN"," ");
define("_STARTDATE","  ");
define("_ADMINEMAIL","Email ");
define("_ITEMSTOP","    ");
define("_STORIESHOME","    ");
define("_OLDSTORIES","    -----");
define("_ACTULTRAMODE","-----");
define("_ALLOWANONPOST","   ;");
define("_DEFAULTTHEME","      ");
define("_SELLANGUAGE","  ()   ");
define("_LOCALEFORMAT","  ");
define("_BANNERSOPT"," -----");
define("_ACTBANNERS","  Banners   () ;");
define("_FOOTERMSG","-----");
define("_FOOTERLINE1","-----");
define("_FOOTERLINE2","-----");
define("_FOOTERLINE3","-----");
define("_FOOTERLINE4","-----");
define("_BACKENDCONF"," ");
define("_BACKENDTITLE","-----");
define("_BACKENDLANG"," ");
define("_MAIL2ADMIN","    ");
define("_NOTIFYSUBMISSION","    email;");
define("_EMAIL2SENDMSG"," email   ");
define("_EMAILSUBJECT","  Email");
define("_EMAILMSG"," Email");
define("_EMAILFROM","Email  ()");
define("_COMMENTSMOD","-----");
define("_MODTYPE","-----");
define("_MODADMIN","-----");
define("_MODUSERS","-----");
define("_NOMOD","-----");
define("_COMMENTSOPT"," ");
define("_COMMENTSLIMIT","    Bytes");
define("_ANONYMOUSNAME","  ");
define("_GRAPHICOPT"," ()  ");
define("_ADMINGRAPHIC","   ");
define("_MISCOPT"," ");
define("_PASSWDLEN","    ");
define("_ACTIVATEHTTPREF"," HTTP ;");
define("_MAXREF","     ;");
define("_COMMENTSPOLLS","   ;");
define("_SECTIONSADMIN"," ");
define("_ACTIVESECTIONS","  () ");
define("_CLICK2EDITSEC","(   )");
define("_ADDSECARTICLE","    ");
define("_SELSECTION"," ");
define("_DONTSELECT",":          -----");
define("_EDITARTID"," ID  ");
define("_ADDSECTION","  ");
define("_SECTIONNAME"," ");
define("_SECTIONIMG"," ");
define("_SECIMGEXAMPLE","(    ///.  .gif)");
define("_ADDSECTIONBUT"," ");
define("_EDITSECTION"," () ");
define("_SECTIONHAS","    ");
define("_ARTICLESATTACH","  ");
define("_40CHARSMAX","(40  )");
define("_DELSECTION"," ");
define("_DELSECWARNING","        ");
define("_DELSECWARNING1","        !");
define("_DELARTICLE"," ");
define("_DELARTWARNING","        ;");
define("_REVADMIN"," Reviews");
define("_REVTITLE","  Reviews");
define("_REVDESC","  Reviews");
define("_REVWAITING","Reviews   ");
define("_TEXT","");
define("_IMAGE","");
define("_REVIMGINFO","  150*150     /reviews");
define("_ADDREVIEW"," Review");
define("_NOREVIEW2ADD","  reviews  ");
define("_CLICK2ADDREVIEW","       review");
define("_DELMODREVIEW"," /  review");
define("_MODREVINFO","   / reviews    <a href=\"modules.php?name=Reviews\">Reviews</a>  .");
define("_LINKSINDB","    ");
define("_LINKSWAITINGVAL","   ");
define("_SUBMITTER","");
define("_VISIT","");
define("_CLEANLINKSDB","   ");
define("_BROKENLINKSREP","-----");
define("_LINKMODREQUEST","  ");
define("_VALIDATELINKS"," ");
define("_ADDMAINCATEGORY","  ");
define("_ADDSUBCATEGORY"," ");
define("_IN","-----");
define("_ADDNEWLINK","  ");
define("_DESCRIPTION255",": (255  )");
define("_MODCATEGORY"," ");
define("_MODLINK"," ");
define("_WEBLINKSADMIN","  ");
define("_ADDEDITORIAL","  ");
define("_EDITORIALTITLE","  ");
define("_EDITORIALTEXT","  ");
define("_AUTHOR","");
define("_DATEWRITTEN","  ");
define("_USERREPBROKEN","----- ");
define("_IGNOREINFO","----- (    <b><i></i></b>    )");
define("_DELETEINFO"," ( <b><i>----- </i></b>  <b><i></i></b>    )");
define("_NOREPORTEDBROKEN","   ");
define("_LINK","");
define("_LINKOWNER"," ");
define("_IGNORE","-----");
define("_USERMODREQUEST","     ");
define("_ORIGINAL","");
define("_SUBCATEGORY","");
define("_PROPOSED","");
define("_OWNER","");
define("_ACCEPT","");
define("_NOMODREQUESTS","        ");
define("_ERRORTHECATEGORY",":  ");
define("_ALREADYEXIST"," !");
define("_ERRORTHESUBCATEGORY",":  ");
define("_EDITORIALADDED","     ");
define("_EDITORIALMODIFIED","  ");
define("_EDITORIALREMOVED","     ");
define("_LINKVALIDATION"," ");
define("_CHECKALLLINKS","   ");
define("_CHECKCATEGORIES"," ");
define("_INCLUDESUBCATEGORIES","( )");
define("_CHECKSUBCATEGORIES"," ");
define("_BEPATIENT","(  )");
define("_VALIDATINGCAT","   (   )");
define("_VALIDATINGSUBCAT","  ");
define("_FAILED","!");
define("_ERRORURLEXIST",":   URL       !");
define("_ERRORNOTITLE",":        URL !");
define("_ERRORNOURL",":      URL   URL !");
define("_ERRORNODESCRIPTION",":       URL!");
define("_NEWLINKADDED","     ");
define("_LINKAPPROVEDMSG","        .");
define("_YOUCANBROWSEUS","       ");
define("_THANKS4YOURSUBMISSION","    !");
define("_TEAM",".");
define("_POLLSADMIN"," / ");
define("_CREATEPOLL","  ");
define("_DELETEPOLLS"," ");
define("_POLLTITLE"," ");
define("_POLLEACHFIELD","     '  ");
define("_CREATEPOLLBUT"," ");
define("_REMOVEEXISTING","  ");
define("_POLLDELWARNING",":          !");
define("_CHOOSEPOLL","       ");
define("_WHOLINKS","    ;");
define("_DELETEREFERERS"," ");
define("_EPHEMADMIN"," ");
define("_ADDEPHEM","  ");
define("_EPHEMDESC"," ");
define("_EPHEMMAINT","  (/)");
define("_EPHEMEDIT"," ");
define("_DOWNLOADSINDB","   ");
define("_DOWNLOADSWAITINGVAL","   ");
define("_CLEANDOWNLOADSDB","  ");
define("_BROKENDOWNLOADSREP","-----");
define("_DOWNLOADMODREQUEST","  ");
define("_VALIDATEDOWNLOADS"," ");
define("_ADDNEWDOWNLOAD","  ");
define("_MODDOWNLOAD"," ");
define("_WEBDOWNLOADSADMIN","  ");
define("_DOWNLOADOWNER","  ");
define("_DOWNLOADVALIDATION"," ");
define("_CHECKALLDOWNLOADS","  ");
define("_NEWDOWNLOADADDED","    ");
define("_SIZE","");
define("_REMOVECOMMENTS"," ");
define("_SURETODELCOMMENTS","              ;");
define("_FAQADMIN"," FAQ");
define("_ACTIVEFAQS"," FAQs");
define("_ID","ID ");
define("_ADDCATEGORY","  ");
define("_QUESTIONS","  ");
define("_ADDQUESTION","  ");
define("_EDITQUESTIONS","   ");
define("_FAQDELWARNING",":         FAQ     ;");
define("_QUESTIONDEL",":         ;");
define("_IMPORTANTNOTE"," ");
define("_BANNERSNOTACTIVE","   Banners   config.php    0,        Banners     .");
define("_TOACTIVATE","   ,     <a href=\"admin.php?op=Configure#banners\"> settings section</a>. ");
define("_ACTIVEBANNERS","  Banners");
define("_IMPRESSIONS","");
define("_IMPLEFT"," ");
define("_CLICKS","");
define("_CLICKSPERCENT","% ");
define("_CLIENTNAME"," ");
define("_FINISHEDBANNERS"," Banners");
define("_IMP",".");
define("_DATESTARTED"," ");
define("_DATEENDED"," ");
define("_ADVERTISINGCLIENTS","  ( )");
define("_ACTIVEBANNERS2"," Banners");
define("_CONTACTNAME","  ");
define("_CONTACTEMAIL","Email ");
define("_ADDNEWBANNER","  Banner");
define("_PURCHASEDIMPRESSIONS"," ");
define("_IMAGEURL"," URL");
define("_CLICKURL","   URL");
define("_ADDBANNER"," Banner");
define("_ADDCLIENT","  ");
define("_CLIENTLOGIN","  ");
define("_CLIENTPASSWD","  ");
define("_ADDCLIENT2"," ");
define("_DELETEBANNER"," Banner");
define("_SURETODELBANNER","       Banner ?");
define("_EDITBANNER"," () Banner");
define("_ADDIMPRESSIONS","  ");
define("_PURCHASED","");
define("_MADE","");
define("_DELETECLIENT","  ");
define("_SURETODELCLIENT","          Banner !!!");
define("_CLIENTWITHOUTBANNERS","      Banner      .");
define("_DELCLIENTHASBANNERS","       BANNERS     ");
define("_EDITCLIENT","  ");
define("_FILENAME","Filename");
define("_FILEINCLUDE","(Select a custom Block to be included. All other fields will be ignored)");
define("_BLOCKFILE","(Block File)");
define("_EDITPOLL","Edit Polls");
define("_CHOOSEPOLLEDIT","Choose the Poll you want to edit:");
define("_ACTIVATECOMMENTS","Activate Comments for this Story?");
define("_COMMENTSARTICLES","Activate Comments in Articles?");
define("_MULTILINGUALOPT","Multilingual Options");
define("_ACTMULTILINGUAL","Activate Multilingual features? ");
define("_ACTUSEFLAGS","Display flags instead of a dropdown box? ");
define("_LANGUAGE","Language");
define("_EDITMSG","Edit message");
define("_ADDMSG","Add message");
define("_ALLMESSAGES","Overview messages");
define("_VIEW","Visible to");
define("_REMOVEMSG","Are you sure you want to remove this message ? ");
define("_ANNOUNCEPOLL","Announce this new Survey in your site");
define("_LEAVEBLANK","(Leave blank to create a new survey without announce it)");
define("_POLLEDIT","Edit Poll:");
define("_ATTACHAPOLL","Attach a Poll to this article");
define("_LEAVEBLANKTONOTATTACH","(Leave blank to post the article without any attached Poll)<br>(NOTE: Automated/Programmed news can't have attached Polls)");
define("_MODULES","Modules");
define("_MODULESADMIN","Modules Administration");
define("_MODULESADDONS","Modules and Addons");
define("_MODULESACTIVATION","See your Modules/Addons current status and change it by Activating or Deactivating them.<br>New Modules copied on the <i>/modules/</i> directory will be automaticaly added with <i>Inactive</i> status to the database when you reload this page.<br>If you want to remove a module just delete it from the <i>/modules/</i> directory, the system will automaticaly update your database to show the changes.");
define("_NEWSLETTER","Newsletter");
define("_MASSMAIL","A Massive e-mail to ALL users");
define("_ANEWSLETTER","A Newsletter to subscribed users only");
define("_WHATTODO","What do you want to send?");
define("_SUBSCRIBEDUSERS","Subscribed Users");
define("_NYOUAREABOUTTOSEND","You're about to send a Newsletter to subscribed users.");
define("_NUSERWILLRECEIVE","Users will receive this Newsletter.");
define("_REVIEWTEXT","Please review and check your text:");
define("_NAREYOUSURE2SEND","Are you sure to send this Newsletter now?");
define("_MYOUAREABOUTTOSEND","You're about to send a Massive e-mail to ALL registered users.");
define("_MUSERWILLRECEIVE","Users will receive this Mail.");
define("_MAREYOUSURE2SEND","Are you sure to send this Massive Email now?");
define("_POSSIBLESPAM","Please note that some users may feel disturbed by massive email and may consider this as Spam!");
define("_MASSEMAIL","Massive Email");
define("_MANYUSERSNOTE","WARNING! There are many users that will receive this text. Please wait until the script finish the operation. This can take some minutes to complete!");
define("_NLUNSUBSCRIBE","=========================================================\nYou're receiving this Newsletter because you selected to receive it from your user page at $sitename.\nYou can unsubscribe from this service by clicking in the following URL:\n\n$nukeurl/modules.php?name=Your_Account&op=edituser\"\n\nthen select \"No\" from the option to Receive Newsletter by Email and save your changes, if you need more assistance please contact $sitename administrator.");
define("_NEWSLETTERSENT","The Newsletter has been sent.");
define("_MASSEMAILSENT","Massive Email to all registered users has been sent.");
define("_MASSEMAILMSG","=========================================================\nYou're receiving this email because you're a registered user of $sitename. We hope that this email didn't disturbed you and in some manner contributes to improve our services.");
define("_BBFORUM","Forum");
define("_BBDELFORUM","Are you sure you want to delete this Forum and ALL its Posts?");
define("_BBDELCAT","Are you sure you want to delete this Category and ALL its Forums and Posts?");
define("_BBAEDITCAT","Edit Categories");
define("_BBACAT","Categories");
define("_BBASAVECHANGES","Save Changes");
define("_BBAFCAT","Forum Categories");
define("_BBAORDER","Order");
define("_BBANOOFF","No. of Forum(s)");
define("_BBAFUNC","Function");
define("_BBAEDIT","Edit");
define("_BBADELETE","Delete");
define("_BBAADDCAT","Add Categories");
define("_BBAADD","Add");
define("_BBACATLOWEST","This category is already the lowest down.");
define("_BBACATHIGHEST","This category is already the highest up.");
define("_BBABACKTOFORUM","Go back to forum admin");
define("_BBAACTIVE","Active");
define("_BBAICONS","Icons");
define("_BBAEMO","Emotions");
define("_BBACODE","Code");
define("_BBAFSMILIES","Forum Smilies");
define("_BBAADDSMILIES","Add Smilies");
define("_BBAEDITSMILIES","Edit Smilies");
define("_BBAACT","Activated");
define("_BBAWARNING","WARNING: Are you sure you want to delete this Smilies?");
define("_BBAYES","Yes");
define("_BBANO","No");
define("_BBAFLISTED","Forum(s) Listed");
define("_BBAFNAME","Forum Name");
define("_BBAFDESC","Forum Description");
define("_BBAFMOD","Moderator");
define("_BBAFACC","Access");
define("_BBATYPE","Type");
define("_BBAANONPOST","Anonymous Posting");
define("_BBAREGUSER","Registered User");
define("_BBAMODADMIN","Moderators/Administrator");
define("_BBAPUBLIC","Public");
define("_BBAPRIVATE","Private");
define("_BBAADDMOREF","Add More Forum for");
define("_BBAACCLEV","Access Level");
define("_BBAEDITF","Edit Forum(s)");
define("_BBAAUP","Forum Categories Order Up");
define("_BBAADOWN","Forum Categories Order Down");
define("_BBACURMOD","Current Moderator");
define("_BBANOMOD","No Moderators Assigned");
define("_BBAREMOVE","Remove");
define("_BBAAMOD","Add Moderator");
define("_BBACHGCAT","Change Categories");
define("_BBAPRIVSET","Add User");
define("_BBAWORD","Word");
define("_BBAREPLACEMENT","Replacement");
define("_BBAADDCENCOR","Add New censor word");
define("_BBAWCS","Forum Word Censor System");
define("_BBAEDITWORD","Edit Censor Word");
define("_BBACENCORWARN","WARNING: Are you sure you want to delete this censor words?");
define("_BBAFBANIP","Current Banned IPs");
define("_BBABANIP","IP Address");
define("_BBADURATION","Durations");
define("_BBAFBANUID","Current Banned UserName");
define("_BBABANUID","Username");
define("_BBAIPUNAME","IP/Username");
define("_BBAADDBAN","Add new banned rules");
define("_BBAWARNBAN","WARNING: Are you sure you want to delete this banned rules?");
define("_BBAEDITPRIVF","Editing Forum Permissions for:");
define("_FIXBLOCKS","Fix Block's Weight Conflicts");
define("_FORUMSADMIN","Forums Administration");
define("_BBSELECTACTION","Select an Administration Task:");
define("_BBAFORUMICONS","Icons");
define("_BBAFORUMCEN","Censure");
define("_BBAFORUMBAN","Ban System");
define("_BBRANKTITLE","Rank Title");
define("_BBRANKMINP","Min. Ranks");
define("_BBRANKMAXP","Max. Ranks");
define("_BBRANKSPEC","Special");
define("_BBRANKIMM","Images");
define("_BBRANKADD","Add New Ranks");
define("_BBEMAILFROM","Email From Address:");
define("_BBEMAILEXPL","(This is the address that will appear on every email sent by the forums)");
define("_BBMAILSIG","Email Signature:");
define("_BBSIGEXPL","(This is the signature that will appear on every email sent by the forums)");
define("_HTMLALLOW","Allow HTML:");
define("_BBCODEALLOW","Allow BBCode:");
define("_BBALLOWSIG","Allow Signatures:");
define("_BBHOT","Hot Topic Threshold:");
define("_BBPPP","Posts Per Page:");
define("_BBPPPEXPL","(This is the number of topics per forum that will be displayed per page of a forum)");
define("_BBTOPPF","Topics Per Forum:");
define("_BBTOPPFEXP","(This is the number of topics per forum that will be displayed per page of a forum)");
define("_EZTRANSFERLINKS","Transfer all links from category");
define("_EZTRANSFER","Transfer");
define("_DELEZLINKCATWARNING","WARNING : Are you sure you want to delete this category ? You will delete all sub-categories and attached links as well !");
define("_EZTHEREIS","There is");
define("_EZSUBCAT","sub-categories");
define("_EZATTACHEDTOCAT","under this category");
define("_EZBROKENLINKS","Broken Links");
define("_CONTENTMANAGER","Content Manager");
define("_DELCONTWARNING","Are you sure you want to delete the page");
define("_DELCONTENT","Delete Page");
define("_SAVEDATABASE","Backup DB");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_ENCYCLOPEDIAMANAGER","Encyclopedia Manager");
define("_DELENCYCLOPEDIA","Delete Encyclopedia");
define("_DELENCYCONTWARNING","Are you sure you want to delete this Encyclopedia and ALL its content?");
define("_DELENCYCLOPEDIATEXT","Delete Encyclopedia Terms");
define("_DELENCYTEXTWARNING","Are you sure you want to delete this Term?");
define("_CURRENTSTATUS","Current Status");
define("_ADDANEWPAGE","Add a New Page");
define("_CSUBTITLE","Sub-Title");
define("_HEADERTEXT","Header Text");
define("_PAGETEXT","Page Text");
define("_FOOTERTEXT","Footer Text");
define("_ACTIVATEPAGE","Activate This Page?");
define("_EDITPAGECONTENT","Edit Page Content");
define("_TERMS","Terms");
define("_ADDNEWENCYCLOPEDIA","Add a New Encyclopedia");
define("_ADDNEWENCYTERM","Add a New Encyclopedia Term");
define("_TERMTEXT","Term Text");
define("_MOVETERMS","Move Terms");
define("_MOVEALLTERMSFROM","Move ALL Terms From");
define("_EDITENCYCLOPEDIA","Edit Encyclopedia");
define("_ENCYTERMSEDIT","Encyclopedia Terms Edit");
define("_SELECTONETERM","Please select one term from the following list:");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_CHANGETOENCY","Change to Encyclopedia");
define("_DBOPTIMIZATION","Database Optimization");
define("_OPTIMIZINGDB","Optimizing the Database:");
define("_TABLE","Table");
define("_SPACESAVED","Space Saved");
define("_ALREADYOPTIMIZED","Already optimized");
define("_OPTIMIZED","Optimized!");
define("_OPTIMIZATIONRESULTS","Optimization Results");
define("_TOTALSPACESAVED","Total Space Saved:");
define("_YOUHAVERUNSCRIPT","You have run this script:");
define("_KBSAVED","Kb saved since its first execution!");
define("_TIMES","times");
define("_CUSTOMTITLE","Custom Title");
define("_CHANGEMODNAME","Change Module Name");
define("_CUSTOMMODNAME","Custom Module Name:");
define("_MODULEEDIT","Modules Edit");
define("_BLOCKFILE2","FILE");
define("_BLOCKSYSTEM","SYSTEM");
define("_DEFHOMEMODULE","Default Homepage Module");
define("_MODULEINHOME","Module Loaded in the Homepage:");
define("_CHANGE","Change");
define("_INHOME","In Home");
define("_MODULEHOMENOTE","<b>-= WARNING =-</b><br>Bold module's title represents the module you have in the Homepage.<br>You can't Deactivate or Restrict this module while it's the default one!<br>If you delete the module's directory you'll see and error in the Homepage.<br>Also, this module has been replaced with <i>Home</i> link in the modules block.");
define("_PUTINHOME","Put in Home");
define("_SURETOCHANGEMOD","Are you sure you want to change your Homepage from");
define("_EZTRANSFERDOWNLOADS","Transfer all downloads from category");
define("_DELEZDOWNLOADSCATWARNING","WARNING : Are you sure you want to delete this category? You will delete all sub-categories and attached downloads as well!");
define("_DELCONTENTCAT","WARNING: Are you sure you want to delete this category? Pages under this category, if they exist, will not be removed, but will not be attached to any category.");
define("_DELCATEGORY","Delete Category");
define("_CENTER","Center");
define("_CENTERBLOCK","Center Block");
define("_ADMINISTRATION","Administration");
define("_NOADMINYET","There are no Administrators Accounts yet, proceeed to create the Super User:");
define("_CREATEUSERDATA","Do you want to create a normal user with the same data?");
 define("_FILESIZE"," ");
 define("_VERSION","");
 define("_HOMEPAGE","  ");
 define("_YOURLINKAT","   ");
define("_NORMAL","Normal");
define("_INACTIVEBANNERS","Inactive Banners");

?>